#install.packages("plotrix")
require(plotrix)

n_col = c(16, 32, 64, 128, 256, 512, 1024)
mle_kl = c(0.08930499, 0.03557426, 0.01712364, 0.00780696, 0.00395585, 0.00196925, 0.00096856)
mle_dev = c(0.12687130, 0.04412715, 0.01865194, 0.00821175, 0.00401772, 0.00201536, 0.00101085)
l2_kl = c(0.08931055, 0.03557713, 0.01712473, 0.00780450, 0.00395578, 0.00196615, 0.00096844)
l2_dev = c(0.0001052, 0.0000558, 0.0000339, 0.0000591, 0.0000655, 0.0001455, 0.0000034)
ice_kl = c(0.07447219, 0.03205559, 0.01601702, 0.00758210, 0.00389944, 0.00193749, 0.00095028)
ice_dev = c(0.03630090, 0.01177874, 0.00414113, 0.00144333, 0.00054323, 0.00027967, 0.00029156)

n_samples = 2000

# Plot the 2 standard deviation error bars.
ice_dev = 2 * ice_dev / sqrt(n_samples)
l2_dev = 2 * l2_dev / sqrt(n_samples)
mle_dev = 2 * mle_dev / sqrt(n_samples)

l2_kl = l2_kl / mle_kl
l2_dev = l2_dev / mle_kl
ice_kl = ice_kl / mle_kl
ice_dev = ice_dev / mle_kl
mle_dev = mle_dev / mle_kl
mle_kl = mle_kl / mle_kl

kl.df <- data.frame(cbind(n_col, mle_kl, l2_kl, ice_kl, mle_dev, l2_dev, ice_dev))


setEPS()
postscript("gaussian-kl.eps")

plotCI(kl.df$n_col, kl.df$ice_kl, col="green", las=1, xlab="N", ylab="KL Divergence", log="y", uiw=kl.df$ice_dev, pch="o", ylim=c(0.8,1.01))
lines(kl.df$n_col, kl.df$mle_kl, col="blue", pch="*")
#points(kl.df$n_col, kl.df$l2_kl, col="red", pch="+")

#plotCI(kl.df$n_col, kl.df$mle_kl, col="blue", las=1, xlab="", ylab="", log="xy", uiw=kl.df$mle_dev, pch="*", axes=FALSE, add=TRUE)
plotCI(kl.df$n_col, kl.df$l2_kl, col="red", las=1, xlab="", ylab="", log="xy", uiw=kl.df$l2_dev, pch="+", axes=FALSE, add=TRUE)




legend(500,0.85,legend=c("mle","ICE","L2"), col=c("blue","green","RED"),
                                   pch=c("*","o","+"),lty=c(1,2,3), ncol=1)
                                   
                                   
dev.off()


sigma_diff = c(0.01339173, 0.00785245, 0.00427886, 0.00224812, 0.00114645, 0.00058393, 0.00028838)
sigma_zscore = c(205.78, 284.00, 351.92, 476.74, 540.59, 437.44, 184.86)

sigma.df <- data.frame(cbind(n_col, sigma_diff, sigma_zscore))


setEPS()
postscript("gaussian-sigma.eps")


plot(sigma.df$n_col, sigma.df$sigma_diff, type="l", col="green", las=1, xlab="N", ylab="Sigma Difference (ICE - MLE)", log="xy", pch="o")
par(new = TRUE)

plot(sigma.df$n_col, sigma.df$sigma_zscore, type="l", axes=FALSE, col="red", las=1, log="x", pch="+", xaxt = "n", yaxt = "n", xlab = "", ylab = "", ylim=c(0,600))
axis(side = 4)
mtext("Z-score", side=4)

legend("topright",legend=c("Sigma Difference","Z-Score"),
  text.col=c("green","red"),pch=c("o", "+"),col=c("green","red"))


dev.off()
